@@ -1,5 +1,3 @@
-import logging
-
 from sendsms.backends.base import BaseSmsBackend
 
 from django_gearman_commands import submit_job
@@ -10,9 +8,6 @@ import django_gearman_proxy.settings
 from django_gearman_proxy import load_object
 
 
-log = logging.getLogger(__name__)
-
-
 PROXY_TASK_NAME = load_command_class('django_gearman_proxy', 'send_sms').task_name
 SERIALIZER = load_object(django_gearman_proxy.settings.GEARMAN_SMS_SERIALIZER)
 
@@ -33,6 +28,7 @@ class SmsBackend(BaseSmsBackend):
                 submit_job(PROXY_TASK_NAME, data=SERIALIZER(msg))
                 sent += 1
             except Exception:
-                log.exception('Error while submitting sms job from gearman sms backend.')
+                if not self.fail_silently:
+                    raise
         return sent
     send_messages.__doc__ = BaseSmsBackend.__doc__ + send_messages.__doc__
\ No newline at end of file
